Trait base::error_chain::ExitCode
source · [−]Expand description
Represents a value that can be used as the exit status of the process.
See quick_main!.
Represents a value that can be used as the exit status of the process.
See quick_main!.