Type Alias c_int

1.64.0 · Source
pub type c_int = i32;
Equivalent to C’s signed int (int) type.

This type will almost always be i32, but may differ on some esoteric systems. The C standard technically only requires that this type be a signed integer that is at least the size of a short; some systems define it as an i16, for example.